@@ -5,6 +5,6 @@ from typing import Any
 @Scalene.shim
 def replacement_mp_get_context(scalene: Scalene) -> None:
     old_get_context = multiprocessing.get_context
-    def replacement_get_context(method: Any):
+    def replacement_get_context(method: Any = None):
         return old_get_context('fork')
     multiprocessing.get_context = replacement_get_context
\ No newline at end of file
